Keyboard shortcuts
------------------

.. note::

    NumKey refers to both the number row keys and numpad keys!

Toolbars
^^^^^^^^

.. list-table:: Main toolbar
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - NumKey{1-0}
      - View output node {0-9}
    * - Ctrl + R
      - Reload script
    * - Ctrl + NumKey{1-0}
      - View output node `last index` - {0-9}, a negative index
    * - Ctrl + Tab
      - View next output node
    * - Ctrl + Shift + Tab
      - View previous output node
    * - S
      - Toggle whether output nodes are synced
    * - V
      - Copy current frame number to clipboard


.. list-table:: Playback toolbar
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Space
      - Play/Pause
    * - Left Arrow
      - Seek to previous frame
    * - Right Arrow
      - Seek to next frame
    * - Shift + Left Arrow
      - Seek back ``n`` (in box) frames
    * - Shift + Right Arrow
      - Seek forward ``n`` (in box) frames
    * - Page Up
      - Seek back ``n`` (in box) frames
    * - Page Down
      - Seek forward ``n`` (in box) frames
    * - Home
      - Seek to first frame
    * - End
      - Seek to last frame

.. list-table:: Misc toolbar
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Ctrl + R
      - Copy frame to clipboard
    * - Ctrl + S
      - Save frame to file
    * - Shift + S
      - Seek to next frame
    * - Alt + S
      - Save storage (both local file and global settings)

.. list-table:: Scening toolbar
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Ctrl + R
      - Copy frame to clipboard
    * - Ctrl + S
      - Save frame to file
    * - Shift + S
      - Seek to next frame
    * - Alt + S
      - Save storage (both local file and global settings)
    * - Shift + F
      - Switch to FFTSpectrum view mode
    * - Shift + D
      - Switch to descale helper view mode

.. list-table:: Scening toolbar
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Ctrl + Space
      - Add current frame as single frame scene
    * - Q
      - Toggle whether current frame is first frame
    * - W
      - Toggle whether current frame is last frame
    * - E
      - Add current A-B selection to current scene list
    * - R
      - Remove current scene from current scene list
    * - Shift + R
      - Switch to descale helper view mode
    * - Ctrl + Left Arrow
      - Seek to previous scene start
    * - Ctrl + Right Arrow
      - Seek to next scene start
    * - Shift + NumKey{1-0}
      - Switch to scene list {0-9}

Dialogs
^^^^^^^

.. list-table:: Settings dialog
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Ctrl + Del
      - Remove selected level from zoom levels list
    * - B
      - Paste current frame number into active scening model

.. list-table:: Scening list view dialog
    :widths: 30 70
    :header-rows: 1

    * - Shortcut
      - Description
    * - Del
      - Delete selected scene
